### Pykern

Pykern is an application support framework to simplify and to speed
development of Python programs and servers.

Pykern defines policies, which make it easy to eliminate boiler-plate.

For more info, [read the API Docs](http://pykern.readthedocs.org).
